@@ -3,13 +3,13 @@
 pub struct CreateConnectionRequest {
     /// Required. Parent resource name.
     /// Must be in the format `projects/{project_id}/locations/{location_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Optional. Connection id that should be assigned to the created connection.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub connection_id: ::prost::alloc::string::String,
     /// Required. Connection to create.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub connection: ::core::option::Option<Connection>,
 }
 /// The request for \[ConnectionService.GetConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.GetConnection\].
@@ -17,7 +17,7 @@ pub struct CreateConnectionRequest {
 pub struct GetConnectionRequest {
     /// Required. Name of the requested connection, for example:
     /// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// The request for \[ConnectionService.ListConnections][google.cloud.bigquery.connection.v1beta1.ConnectionService.ListConnections\].
@@ -25,23 +25,23 @@ pub struct GetConnectionRequest {
 pub struct ListConnectionsRequest {
     /// Required. Parent resource name.
     /// Must be in the form: `projects/{project_id}/locations/{location_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Required. Maximum number of results per page.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub max_results: ::core::option::Option<u32>,
     /// Page token.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub page_token: ::prost::alloc::string::String,
 }
 /// The response for \[ConnectionService.ListConnections][google.cloud.bigquery.connection.v1beta1.ConnectionService.ListConnections\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListConnectionsResponse {
     /// Next page token.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub next_page_token: ::prost::alloc::string::String,
     /// List of connections.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub connections: ::prost::alloc::vec::Vec<Connection>,
 }
 /// The request for \[ConnectionService.UpdateConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.UpdateConnection\].
@@ -49,13 +49,13 @@ pub struct ListConnectionsResponse {
 pub struct UpdateConnectionRequest {
     /// Required. Name of the connection to update, for example:
     /// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Required. Connection containing the updated fields.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub connection: ::core::option::Option<Connection>,
     /// Required. Update mask for the connection fields to be updated.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
 /// The request for \[ConnectionService.UpdateConnectionCredential][google.cloud.bigquery.connection.v1beta1.ConnectionService.UpdateConnectionCredential\].
@@ -63,10 +63,10 @@ pub struct UpdateConnectionRequest {
 pub struct UpdateConnectionCredentialRequest {
     /// Required. Name of the connection, for example:
     /// `projects/{project_id}/locations/{location_id}/connections/{connection_id}/credential`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Required. Credential to use with the connection.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub credential: ::core::option::Option<ConnectionCredential>,
 }
 /// The request for \[ConnectionService.DeleteConnectionRequest][\].
@@ -74,7 +74,7 @@ pub struct UpdateConnectionCredentialRequest {
 pub struct DeleteConnectionRequest {
     /// Required. Name of the deleted connection, for example:
     /// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// Configuration parameters to establish connection with an external data
@@ -83,25 +83,25 @@ pub struct DeleteConnectionRequest {
 pub struct Connection {
     /// The resource name of the connection in the form of:
     /// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// User provided display name for the connection.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub friendly_name: ::prost::alloc::string::String,
     /// User provided description.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub description: ::prost::alloc::string::String,
     /// Output only. The creation timestamp of the connection.
-    #[prost(int64, tag = "5")]
+    #[prost(int64, tag="5")]
     pub creation_time: i64,
     /// Output only. The last update timestamp of the connection.
-    #[prost(int64, tag = "6")]
+    #[prost(int64, tag="6")]
     pub last_modified_time: i64,
     /// Output only. True, if credential is configured for this connection.
-    #[prost(bool, tag = "7")]
+    #[prost(bool, tag="7")]
     pub has_credential: bool,
     /// Properties specific to the underlying data source.
-    #[prost(oneof = "connection::Properties", tags = "4")]
+    #[prost(oneof="connection::Properties", tags="4")]
     pub properties: ::core::option::Option<connection::Properties>,
 }
 /// Nested message and enum types in `Connection`.
@@ -110,7 +110,7 @@ pub mod connection {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Properties {
         /// Cloud SQL properties.
-        #[prost(message, tag = "4")]
+        #[prost(message, tag="4")]
         CloudSql(super::CloudSqlProperties),
     }
 }
@@ -118,7 +118,7 @@ pub mod connection {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ConnectionCredential {
     /// Credential specific to the underlying data source.
-    #[prost(oneof = "connection_credential::Credential", tags = "1")]
+    #[prost(oneof="connection_credential::Credential", tags="1")]
     pub credential: ::core::option::Option<connection_credential::Credential>,
 }
 /// Nested message and enum types in `ConnectionCredential`.
@@ -127,7 +127,7 @@ pub mod connection_credential {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Credential {
         /// Credential for Cloud SQL database.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         CloudSql(super::CloudSqlCredential),
     }
 }
@@ -135,16 +135,16 @@ pub mod connection_credential {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CloudSqlProperties {
     /// Cloud SQL instance ID in the form `project:location:instance`.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub instance_id: ::prost::alloc::string::String,
     /// Database name.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub database: ::prost::alloc::string::String,
     /// Type of the Cloud SQL database.
-    #[prost(enumeration = "cloud_sql_properties::DatabaseType", tag = "3")]
+    #[prost(enumeration="cloud_sql_properties::DatabaseType", tag="3")]
     pub r#type: i32,
     /// Input only. Cloud SQL credential.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub credential: ::core::option::Option<CloudSqlCredential>,
 }
 /// Nested message and enum types in `CloudSqlProperties`.
@@ -165,17 +165,17 @@ pub mod cloud_sql_properties {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CloudSqlCredential {
     /// The username for the credential.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub username: ::prost::alloc::string::String,
     /// The password for the credential.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub password: ::prost::alloc::string::String,
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod connection_service_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Manages external data source connections and credentials."]
+    /// Manages external data source connections and credentials.
     #[derive(Debug, Clone)]
     pub struct ConnectionServiceClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -183,8 +183,8 @@ pub mod connection_service_client {
     impl<T> ConnectionServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -203,196 +203,230 @@ pub mod connection_service_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             ConnectionServiceClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Creates a new connection."]
+        /// Creates a new connection.
         pub async fn create_connection(
             &mut self,
             request: impl tonic::IntoRequest<super::CreateConnectionRequest>,
         ) -> Result<tonic::Response<super::Connection>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/CreateConnection",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Returns specified connection."]
+        /// Returns specified connection.
         pub async fn get_connection(
             &mut self,
             request: impl tonic::IntoRequest<super::GetConnectionRequest>,
         ) -> Result<tonic::Response<super::Connection>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/GetConnection",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Returns a list of connections in the given project."]
+        /// Returns a list of connections in the given project.
         pub async fn list_connections(
             &mut self,
             request: impl tonic::IntoRequest<super::ListConnectionsRequest>,
         ) -> Result<tonic::Response<super::ListConnectionsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/ListConnections",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Updates the specified connection. For security reasons, also resets"]
-        #[doc = " credential if connection properties are in the update field mask."]
+        /// Updates the specified connection. For security reasons, also resets
+        /// credential if connection properties are in the update field mask.
         pub async fn update_connection(
             &mut self,
             request: impl tonic::IntoRequest<super::UpdateConnectionRequest>,
         ) -> Result<tonic::Response<super::Connection>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/UpdateConnection",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Sets the credential for the specified connection."]
+        /// Sets the credential for the specified connection.
         pub async fn update_connection_credential(
             &mut self,
             request: impl tonic::IntoRequest<super::UpdateConnectionCredentialRequest>,
         ) -> Result<tonic::Response<()>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http :: uri :: PathAndQuery :: from_static ("/google.cloud.bigquery.connection.v1beta1.ConnectionService/UpdateConnectionCredential") ;
+            let path = http::uri::PathAndQuery::from_static(
+                "/google.cloud.bigquery.connection.v1beta1.ConnectionService/UpdateConnectionCredential",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Deletes connection and associated credential."]
+        /// Deletes connection and associated credential.
         pub async fn delete_connection(
             &mut self,
             request: impl tonic::IntoRequest<super::DeleteConnectionRequest>,
         ) -> Result<tonic::Response<()>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/DeleteConnection",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Gets the access control policy for a resource."]
-        #[doc = " Returns an empty policy if the resource exists and does not have a policy"]
-        #[doc = " set."]
+        /// Gets the access control policy for a resource.
+        /// Returns an empty policy if the resource exists and does not have a policy
+        /// set.
         pub async fn get_iam_policy(
             &mut self,
             request: impl tonic::IntoRequest<
                 super::super::super::super::super::iam::v1::GetIamPolicyRequest,
             >,
         ) -> Result<
-            tonic::Response<super::super::super::super::super::iam::v1::Policy>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<super::super::super::super::super::iam::v1::Policy>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/GetIamPolicy",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Sets the access control policy on the specified resource. Replaces any"]
-        #[doc = " existing policy."]
-        #[doc = ""]
-        #[doc = " Can return Public Errors: NOT_FOUND, INVALID_ARGUMENT and PERMISSION_DENIED"]
+        /// Sets the access control policy on the specified resource. Replaces any
+        /// existing policy.
+        ///
+        /// Can return Public Errors: NOT_FOUND, INVALID_ARGUMENT and PERMISSION_DENIED
         pub async fn set_iam_policy(
             &mut self,
             request: impl tonic::IntoRequest<
                 super::super::super::super::super::iam::v1::SetIamPolicyRequest,
             >,
         ) -> Result<
-            tonic::Response<super::super::super::super::super::iam::v1::Policy>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<super::super::super::super::super::iam::v1::Policy>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/SetIamPolicy",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Returns permissions that a caller has on the specified resource."]
-        #[doc = " If the resource does not exist, this will return an empty set of"]
-        #[doc = " permissions, not a NOT_FOUND error."]
-        #[doc = ""]
-        #[doc = " Note: This operation is designed to be used for building permission-aware"]
-        #[doc = " UIs and command-line tools, not for authorization checking. This operation"]
-        #[doc = " may \"fail open\" without warning."]
+        /// Returns permissions that a caller has on the specified resource.
+        /// If the resource does not exist, this will return an empty set of
+        /// permissions, not a NOT_FOUND error.
+        ///
+        /// Note: This operation is designed to be used for building permission-aware
+        /// UIs and command-line tools, not for authorization checking. This operation
+        /// may "fail open" without warning.
         pub async fn test_iam_permissions(
             &mut self,
             request: impl tonic::IntoRequest<
                 super::super::super::super::super::iam::v1::TestIamPermissionsRequest,
             >,
         ) -> Result<
-            tonic::Response<super::super::super::super::super::iam::v1::TestIamPermissionsResponse>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<
+                    super::super::super::super::super::iam::v1::TestIamPermissionsResponse,
+                >,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.bigquery.connection.v1beta1.ConnectionService/TestIamPermissions",
